@@ -17,7 +17,7 @@ from openai import OpenAI
 from jinja2 import Environment, FileSystemLoader
 
 
-VERSION = "0.10.3"
+VERSION = "0.10.4"
 
 BLUE = "\033[94m"
 GREEN = "\033[92m"
@@ -216,8 +216,7 @@ def display_cve_data(cve_data, error=None):
         cve_item = data["containers"]["cna"]
         published = data["cveMetadata"].get("datePublished", "")
         if published:
-            published_date = datetime.datetime.fromisoformat(
-                published.rstrip("Z"))
+            published_date = datetime.datetime.fromisoformat(published.rstrip("Z"))
             published = published_date.strftime("%Y-%m-%d")
         description = (
             next(
@@ -234,8 +233,10 @@ def display_cve_data(cve_data, error=None):
         wrapped_description = textwrap.fill(
             description, width=100, subsequent_indent=" " * 15
         )
+
         metrics = cve_item.get("metrics", [])
         baseScore, baseSeverity, vectorString = "N/A", "N/A", "N/A"
+
         for metric in metrics:
             cvss_data = metric.get("cvssV3_1") or metric.get("cvssV3")
             if cvss_data:
@@ -244,6 +245,21 @@ def display_cve_data(cve_data, error=None):
                 vectorString = cvss_data.get("vectorString", "N/A")
                 if baseScore != "N/A":
                     break
+        
+        if baseScore == "N/A":
+            adp = data["containers"].get("adp", [])
+            for adp_entry in adp:
+                for metric in adp_entry.get("metrics", []):
+                    cvss_data = metric.get("cvssV3_1") or metric.get("cvssV3")
+                    if cvss_data:
+                        baseScore = cvss_data.get("baseScore", "N/A")
+                        baseSeverity = cvss_data.get("baseSeverity", "N/A")
+                        vectorString = cvss_data.get("vectorString", "N/A")
+                        if baseScore != "N/A":
+                            break
+                if baseScore != "N/A":
+                    break
+
         return [
             f"├ Published:   {published}",
             f"├ Base Score:  {baseScore} ({baseSeverity})",
@@ -292,7 +308,7 @@ def display_cisa_status(cve_id, cisa_data, error=None):
 
 
 def display_public_exploits(github_data, vulncheck_data, exploitdb_data, packetstorm_data, nuclei_data, vulncheck_error=None):
-    def template(data):
+    def template():
         total_exploits = 0
         entries = []
 
@@ -358,11 +374,11 @@ def display_public_exploits(github_data, vulncheck_data, exploitdb_data, packets
             entries.append(f"   └ {other_entries[-1]}")
 
         if not entries:
-            return ["└ ❌ No data found."]
+            return ["└ ❌ No data found."], total_exploits
 
         return entries, total_exploits
 
-    exploits, total = template(True)
+    exploits, total = template()
     print(f"┌───[ {BLUE}💣 Public Exploits (Total: {total}){ENDC} ]")
     if exploits:
         print("|")
@@ -373,6 +389,7 @@ def display_public_exploits(github_data, vulncheck_data, exploitdb_data, packets
         print("|")
         print(f"└ ❌ No data found.\n")
 
+
 def display_hackerone_data(hackerone_data, error=None):
     def template(data):
         if not data or "data" not in data or "cve_entry" not in data["data"]:
